#!/bin/bash
# respawn.h name [logfile]
# This script will launch an application (name supplied on cmd line)
# and then monitor for its termination. It will respawn it if it terminates
# after a 3s pause. 
# Crash logging can be turned on by providing a log file name
# on the command line. Each time an event is logged only the last 100 lines of the
# old log are kept to minimise disk usage creep

if [ -z "$1" ]
then
	echo No Application name supplied
	exit
fi

if [ ! -x $1 ]
then
	echo Application "$1" does not exist or is not executable
	exit
fi

echo Spawning $1

# log the initial startup from reset
if [ -z "$2" ]
then
	echo No Logging
else
	sudo chmod 666 $2
	tail -n 100 $2 > $2.tmp
	rm $2
	mv $2.tmp $2
	rm $2.tmp
	date >> $2
	echo Reset >> $2
fi

declare -i exitCode

# spawn the code and monitor it
until $1; do
	exitCode=$?
	echo "##############################################################"
	echo "$1 terminated with exit code $exitCode. Respawning.."
	echo "##############################################################"
	sleep 3
	if [ -z "$2" ]
	then
		echo No Logging
	else
		sudo chmod 666 $2
		tail -n 100 $2 > $2.tmp
		rm $2
		mv $2.tmp $2
		rm $2.tmp
		date >> $2
		echo "$1 Exit with code $exitCode" >> $2
	fi
done

echo "$1 terminated permanently"
date >> $2
echo "$1 terminated permanently" >> $2
